import React from 'react';
import type { Metadata } from 'next';
import { notFound } from 'next/navigation';

export const metadata: Metadata = {
    title: 'Bbuddy - Blog item',
    description: 'Bbuddy desc blog item'
};

export function generateStaticParams() {
    return [{ blogId: 'news-1' }, { blogId: 'news-2' }];
}

export default function BlogItem({ params }: { params: { blogId: string } }) {
    if (!params?.blogId) notFound();

    return (
        <div className="b-news-page">
            <div className="b-inner">
                <h1 className="b-news-page__title">6 learnings from Shivpuri to Silicon Valley</h1>
                <div className="news-item__badge">Leadership & Management</div>
                <div className="b-news-page__text">
                    {`news id ${params.blogId}`}<br />
                    I’m excited to kick off this series of newsletters where I’ll be sharing my experiences, learnings,
                    and best practices which helped me to grow both in my personal and professional life. My hope is to
                    give back to the community and help anyone connect directly with me who may have got impacted with
                    recent layoffs, dealing with immigration challenges.
                </div>
                <div className="b-news-page__image">
                    <img className="" src="/images/news1.png" alt="" />
                </div>
                <div className="news-item__info">
                    <div className="news-item__info__author">
                        <img className="" src="/images/author.png" alt="" />
                        <div className="news-item__info__author__inner">
                            <div className="news-item__info__name">Sonali Garg</div>
                            <div className="news-item__info__date">February 6th, 2023</div>
                        </div>
                    </div>
                    <div className="news-item__info__counter">
                        <div className="news-item__info__like">
                            <img className="" src="/images/heart-outline.svg" alt="" />
                            165
                        </div>
                        <div className="news-item__info__share">
                            <img className="" src="/images/share-social.svg" alt="" />
                            Share
                        </div>
                    </div>
                </div>
                <div className="b-news-page__inner">
                    <h2 className="title-h2">
                        This is not about layoffs, it's about living with whatever life throws at you..
                    </h2>
                    <p className="b-news-page__text">
                        Over the past few months, as the macro-economic events have unfolded, I have heard voices filled
                        with anxiety, helplessness and general lack of confidence to deal with this ambiguity from my
                        mentees, colleagues, friends and family. I was laid off from Meta last November and I firmly
                        believe this is nothing but a bump in the road that might seem like a steep climb in the
                        short-term. I may not have all the answers but this has inspired me to share my story. If you
                        are looking for a sob story, you can stop reading now. Ever wondered what it takes for a girl
                        born into a conservative family in a small sleepy town in India, who lost one of her parents at
                        age 17, earned her living while pursuing engineering, moved to the UK by herself and ended up
                        working in big tech in Silicon valley? My goal with this series of posts is to inspire and share
                        my mental models that helped me throughout my professional and personal life.
                    </p>
                    <p className="b-news-page__text">
                        After completing my engineering, I started my career at a small software company in Bhopal and
                        then worked for TCS(Tata Consultancy Services), one of the largest IT-outsourcing companies in
                        the world for almost 5 years. Over the past 14 years, I have worked for big tech companies like
                        Meta (Facebook) and Google, wore multiple hats, led strategic programs, scaled multi
                        billion-dollar businesses, built teams and helped achieve business operational excellence.
                        Throughout my career, I’ve dealt with several challenges from execution to scale to building a
                        high performance team. A lot of my early struggles were about how to assimilate in a new
                        culture, create a network in a new environment, earn trust, create and nurture work
                        relationships into fruitful friendships and so on.
                    </p>
                    <p className="b-news-page__text">
                        I was born in a conservative family in a small town called ‘Shivpuri’, also known as ‘Mini
                        Kashmir’ because of its natural beauty. My father was a civil engineer working on Madikheda Dam
                        on Sindh river and was a strict disciplinarian. He was gone from dawn to dusk and was always
                        focused. My mother was a teacher in a school that was about 30 kms from our home. We (me and my
                        sister) would often be left with neighbors to be taken care of and this led us to become
                        independent at an early age. Our otherwise slow paced, simple life with only a few families
                        around in the government quarters that were set up to support construction of the dam was filled
                        with natural beauty, wildlife and a community of close friends. Our lives were balanced and
                        while my parents worked hard to provide basic needs, we were satisfied. There were only a few
                        schools with Hindi being the prevalent language as the medium of teaching. There were no
                        colleges for advanced studies and most girls did not go to college often married off by their
                        18th birthday. Generally speaking, we had a joyous childhood with just the basics. While most
                        folks we interacted with were not highly educated nor ambitious, earned lower middle class
                        salaries and lacked exposure to the outside world but there was plenty to learn from them.
                        People had learnt to stick together in good and bad times. They embodied the old school
                        qualities of hard work, dedication and commitment. Be willing to give it all- hard work,
                        dedication and commitment.
                    </p>
                    <p className="b-news-page__text">
                        In 2003, my father passed away suddenly and we found ourselves in crisis. My mother was a
                        teacher and she did not have time to deal with her grief. Rather, she was struggling to garner
                        support to get transferred to a school in Bhopal, capital of Madhya Pradesh to be closer to our
                        maternal grandparents. As we uprooted ourselves from Shivpuri to Bhopal, one of my father’s
                        loyal friends came to help load the moving truck. While he had nothing to gain out of us, he
                        continued to serve us until the last day in Shivpuri. Remember, in crisis your team matters more
                        than any other time. Advocate for them ruthlessly in good and bad times, they will come through
                        in crisis.
                    </p>
                    <p className="b-news-page__text">
                        Eventually we found our footing, my mother’s job was transferred to a local school in Bhopal and
                        I got admission in a government engineering college. My sister was still attending high school
                        and both of us were teaching tuition classes to middle school students in the evenings to make
                        ends meet. I also started a tiffin service for a few out of town students while attending
                        college to pay for my transportation and cost of supplies. We refused to give up. Persevere when
                        all else fails.
                    </p>
                    <p className="b-news-page__text">
                        Our 5 years went by quickly in Bhopal as we worked towards improving our financial situation and
                        I completed my Bachelors in Computer Science. This was the time I first stepped out to live in a
                        metropolitan city, Mumbai for my job at TCS. This was a paradigm shift from Bhopal and I was
                        blown away to meet so many talented folks in Mumbai. In my head, I did not belong in this place.
                        I had imposter syndrome and felt like an outsider trying to make it in a new city. Most people I
                        met were fluent in more than 1 language, well-dressed, communicated openly and with confidence,
                        and presented themselves well. I was always in a dilemma when it came to adopting values. It
                        took me a while to adjust to it but I was still not confident about my work and communication
                        while my hard skills that I learnt in engineering were top notch. I kept questioning my
                        abilities but persisted. This was not the first time I was out of my comfort zone. Persist, when
                        in discomfort.
                    </p>
                    <p className="b-news-page__text">
                        I worked with multiple global companies who were clients of TCS and was presented an opportunity
                        to move to Scotland, UK for an year to work for GE, who was also a client. This was my first
                        opportunity to explore a different culture, food, music, languages etc. I remember working on my
                        english when in Mumbai, in preparation for my UK trip. It was really difficult to understand the
                        accent in the UK, even though language was not a barrier. I still remember certain words would
                        just not get across no matter how hard some of my colleagues tried and they would end up using
                        signs to convey. Be prepared, opportunities come to those who are prepared.
                    </p>
                    <p className="b-news-page__text">
                        In 2013, I came to the US on a dependent visa after marriage and quickly realized the curse of
                        H4 visa. I paved my path by going back to school at UC Berkeley and then jumped back into
                        building my career from scratch. While working in the US over the past years, I realized college
                        degrees with good grades and certifications definitely help you to get your foot in the door but
                        are not enough to be successful in your career. As I was again starting from scratch in a new
                        culture, determined to do whatever it takes, having done this a few times before, it doesn’t
                        scare me as much. Never be afraid to start from zero again!
                    </p>
                </div>
            </div>
        </div>
    );
};
