'use client';

import React, { useCallback, useState } from 'react';
import { Button } from 'antd';
import { useSearchParams } from 'next/navigation';
import { useRouter } from '../../navigation';
import { AdditionalFilter } from '../../types/experts';
import { LOCALES } from '../../constants/locale';
import { getObjectByFilter, getObjectByAdditionalFilter } from '../../utils/filter';
import { CustomInput, CustomSelect, CustomMultiSelect } from '../view';

type ExpertAdditionalFilterProps = {
    searchPlaceholder: string;
    sortLabel: string;
    langLabel: string;
    buttonFind: string;
    basePath: string;
};

export const ExpertsAdditionalFilter = ({
    searchPlaceholder,
    sortLabel,
    langLabel,
    buttonFind,
    basePath,
}: ExpertAdditionalFilterProps) => {
    const searchParams = useSearchParams();
    const router = useRouter();
    const [filter, setFilter] = useState<AdditionalFilter | undefined>(getObjectByAdditionalFilter(searchParams));

    const onChangeInput = useCallback((e: any) => {
        if (e?.target?.value) {
            setFilter({
                ...filter,
                text: e.target.value
            });
        } else {
            if (filter?.text) {
                const newFilter = { ...filter };
                delete newFilter.text;

                setFilter(newFilter);
            }
        }
    }, [filter]);

    const onChangeSort = useCallback((value: string) => {
        const newFilter: AdditionalFilter = { ...filter };

        if (value) {
            newFilter.sort = value;
        } else {
            delete newFilter?.sort;
        }

        setFilter(newFilter);
    }, [filter]);

    const onChangeLang = useCallback((value: string[]) => {
        const newFilter: AdditionalFilter = { ...filter };

        if (value.length > 0) {
            newFilter.language = value;
        } else {
            delete newFilter?.language;
        }

        setFilter(newFilter);
    }, [filter]);

    const goToFilterPage = useCallback(() => {
        router.push({
            pathname: basePath as any,
            query: {
                ...getObjectByFilter(searchParams),
                ...filter
            }
        })
    }, [filter, searchParams, router]);

    return (
        <div className="main-find__search">
            <div className="main-find__search__input">
                <CustomInput
                    placeholder={searchPlaceholder}
                    defaultValue={filter?.text}
                    onChange={onChangeInput}
                />
            </div>
            <div className="main-find__search__sort">
                <CustomSelect
                    label={sortLabel}
                    value={filter?.sort}
                    onChange={onChangeSort}
                    options={[
                        { value: 'byTop', label: 'By top views' },
                        { value: 'byPriceAsc', label: 'By price ascending' },
                        { value: 'byPriceDesc', label: 'By price descending' },
                        { value: 'byRating', label: 'By rating' }
                    ]}
                />
            </div>
            <div className="main-find__search__language">
                <CustomMultiSelect
                    label={langLabel}
                    value={filter?.language}
                    onChange={onChangeLang}
                    options={Object.entries(LOCALES).map(([ value, label ]) => ({ value, label }))}
                />
            </div>
            <Button
                className="btn-apply"
                onClick={goToFilterPage}
            >
                {buttonFind}
            </Button>
        </div>
    );
};
