import React, { FC } from 'react';
import { useTranslations } from 'next-intl';
import { HeaderMenu } from './HeaderMenu';
import { LanguageSwitcher } from './LanguageSwitcher';
import { HeaderMobileMenu } from './HeaderMobileMenu';
import { HEAD_ROUTES } from '../../../constants/routes';
import { Link } from '../../../navigation';

type HeaderProps = {
    locale: string;
};

export const Header: FC<HeaderProps> = ({ locale }) => {
    const t = useTranslations('Header');

    const routes: { path: string, title: string }[] = HEAD_ROUTES.map((item) => ({
        path: item,
        title: t(`menu.${item}`)
    }));

    return (
        <>
            <header className="b-header">
                <div className="b-inner">
                    <Link href={'/' as any} className="b-header__logo">
                        <img
                            src="/images/logo-header.svg"
                            className="img-default"
                            alt=""
                        />
                    </Link>
                    <HeaderMenu
                        enterTitle={t('enter')}
                        registerTitle={t('registration')}
                        accountTitle={t('account')}
                        linkConfig={routes}
                    />
                    <LanguageSwitcher locale={locale} />
                </div>
            </header>
            <HeaderMobileMenu
                enterTitle={t('enter')}
                registerTitle={t('registration')}
                accountTitle={t('account')}
                linkConfig={routes}
            />
        </>
    );
};
