import React, {useEffect, useState} from 'react';
import styled from 'styled-components';
import { Select as AntdSelect, Tag } from 'antd';
import type { SelectProps } from 'antd';

type TagRender = SelectProps['tagRender'];

const Select = styled(AntdSelect)`
    width: 100% !important;
    height: 54px !important;

    .ant-select-selector {
        background-color: #F8F8F7 !important;
        border-color: #F8F8F7 !important;
        border-radius: 8px !important;
        padding: 22px 16px 8px !important;
        box-shadow: none !important;
        
        .ant-select-selection-item {
            font-size: 15px !important;
            font-weight: 400 !important;
            line-height: 24px !important;
            color: #313131 !important;
        }
    }
    
    .ant-select-selection-overflow-item {
        margin-right: 4px;
    }
    
    .ant-select-arrow {
        color: #2c7873 !important;
    }
    
    &.ant-select-focused, &:hover {
        .ant-select-selector {
            border-color: #2c7873 !important;
            box-shadow: none !important;
        }
    }
`;

const SelectWrap = styled.div`
    position: relative;
    width: 100%;
`;

const SelectLabel = styled.div`
    font-size: 15px;
    font-style: normal;
    font-weight: 400;
    line-height: 24px;
    color: #000;
    opacity: .3;
    position: absolute;
    left: 16px;
    top: 15px;
    z-index: 1;
    transition: all .1s ease;
    
    .b-multiselect__active & {
        font-size: 12px;
        font-weight: 300;
        line-height: 14px;
        top: 8px;
    }
`;

const tagRender: TagRender = (props) => {
    const { label } = props;

    return (
        <Tag className="skills__list__item">
            {label}
        </Tag>
    );
};

export const CustomMultiSelect = (props: any) => {
    const { label, value, ...other } = props;
    const [isActiveLabel, setIsActiveLabel] = useState<boolean>(false);

    useEffect(() => {
        if (label) {
            setIsActiveLabel(!!value?.length);
        } else {
            setIsActiveLabel(false);
        }
    }, [value]);

    return (
        <SelectWrap className={isActiveLabel ? 'b-multiselect__active' : ''}>
            <SelectLabel>{label}</SelectLabel>
            <Select
                mode="multiple"
                value={value}
                showSearch={false}
                maxTagCount="responsive"
                tagRender={tagRender}
                onFocus={!isActiveLabel ? () => setIsActiveLabel(true) : undefined}
                onBlur={() => setIsActiveLabel(!!value?.length)}
                {...other}
            />
        </SelectWrap>
    );
};
