import { SearchData } from '../types/tags';
import { AdditionalFilter, Filter } from '../types/experts';

export const getDefaultFilter = (searchData: SearchData | null): Filter => {
    const themesTagIds = searchData?.themesGroups?.reduce<number[]>((result, { tags }) => {
        const t = tags?.map(({ id }) => id) || [];

        return t ? [
            ...result,
            ...t
        ] : result;
    }, []);

    return {
        themesTagIds,
        priceFrom: null,
        priceTo: null,
        durationFrom: null,
        durationTo: null
    } as Filter;
};

export const getFilter = (searchData: SearchData | null, searchParams?: { [key: string]: string | string[] | undefined }): Filter => {
    const filter = getDefaultFilter(searchData);

    if (searchParams) {
        const { themesTagIds, priceFrom, priceTo, durationFrom, durationTo } = searchParams;

        if (themesTagIds) {
            if (Array.isArray(themesTagIds) && themesTagIds?.length > 0) {
                filter.themesTagIds = themesTagIds.map((id) => +id);
            }

            if (typeof themesTagIds === 'string') {
                filter.themesTagIds = [+themesTagIds];
            }
        }

        if (priceFrom) {
            filter.priceFrom = +priceFrom;
        }

        if (priceTo) {
            filter.priceTo = +priceTo;
        }

        if (durationFrom) {
            filter.durationFrom = +durationFrom;
        }

        if (durationTo) {
            filter.durationTo = +durationTo;
        }
    }

    return filter;
};

export const getObjectByFilter = (searchParams?: any): Filter | undefined => {
    const filter: Filter = {};

    let tags = searchParams?.getAll('themesTagIds');

    if (tags && tags.length > 0) {
        filter.themesTagIds = tags.map((id: string) => Number(id));
    }

    if (searchParams?.has('priceFrom')) {
        filter.priceFrom = Number(searchParams.get('priceFrom'));
    }

    if (searchParams?.has('priceTo')) {
        filter.priceTo = Number(searchParams.get('priceTo'));
    }

    if (searchParams?.has('durationFrom')) {
        filter.durationFrom = Number(searchParams.get('durationFrom'));
    }

    if (searchParams?.has('durationTo')) {
        filter.durationTo = Number(searchParams.get('durationTo'));
    }

    return filter;
};

export const getObjectByAdditionalFilter = (searchParams?: any): AdditionalFilter => {
    const additionalFilter: AdditionalFilter = {};

    if (searchParams?.has('text')) {
        additionalFilter.text = searchParams.get('text');
    }

    if (searchParams?.has('sort')) {
        additionalFilter.sort = searchParams.get('sort');
    }

    if (searchParams?.has('language')) {
        additionalFilter.language = searchParams.getAll('language');
    }

    return additionalFilter;
};
